IntoCanonical

Trait IntoCanonical 

pub trait IntoCanonical {
    // Required method
    fn into_canonical(self) -> CanonicalError;
}
Helper trait for converting concrete error types into CanonicalError.

Prefer impl From<E> for CanonicalError for new error types — this trait exists for cases where the conversion is performed through a dynamic downcast (see map_error_to_canonical).

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoCanonical for Error

Source

impl IntoCanonical for Error

Implementors