Module bootstrap

Module bootstrap 

Unified bootstrap library for Gears Toolkit gears

This crate provides bootstrap functionality for both host (in-process) and OoP (out-of-process) Toolkit gears.

Gears

  • config: Configuration types and utilities
  • host: Host/in-process bootstrap - logging, signals, and paths
  • oop: Out-of-process gear bootstrap - lifecycle management with DirectoryService (requires the oop feature)

Backends

Backend types for spawning OoP gears have been moved to toolkit::backends.

Re-exports

pub use config::AppConfig;
pub use config::CliArgs;
pub use config::ConsoleFormat;
pub use config::GearConfig;
pub use config::GearRuntime;
pub use config::LoggingConfig;
pub use config::RenderedGearConfig;
pub use config::RuntimeKind;
pub use config::Section;
pub use config::ServerConfig;
pub use config::TOOLKIT_MODULE_CONFIG_ENV;
pub use config::VendorConfig;
pub use config::VendorConfigError;
pub use config::dump_effective_gears_config_json;
pub use config::dump_effective_gears_config_yaml;
pub use config::list_gear_names;
pub use config::render_effective_gears_config;
pub use oop::OopRunOptions;
pub use oop::run_oop_with_options;

Modules

config
Configuration gear for toolkit-bootstrap
host
Host/in-process bootstrap gear
oop
Out-of-process gear bootstrap library

Enums

CryptoProviderError
Error returned when the crypto provider cannot be installed.

Functions

init_crypto_provider
Install the process-wide default rustls CryptoProvider.
run_migrate
Run database migrations and exit.
run_server
Errors