Bounded exponential-backoff retry helper used by generated clients.
Functions
- retry_
with_ backoff - Run
fwith bounded exponential backoff while it returns transient errors.
Bounded exponential-backoff retry helper used by generated clients.
f with bounded exponential backoff while it returns transient errors.