Modules
- shutdown
- Shutdown signal handling utilities
Structs
- Client
Registration - A type-erased client registration for injecting clients into the
ClientHub. - Endpoint
- Represents an endpoint where a gear instance can be reached
- Gear
Installers - Installers for a specific gear (gear name + service installers).
- Gear
Instance - Represents a single instance of a gear
- Gear
Manager - Central registry that tracks all running gear instances in the system. Provides discovery, health tracking, and round-robin load balancing.
- Grpc
Installer Data - Grouped installers for all gears in the process.
- Grpc
Installer Store - Runtime-owned store for gRPC service installers.
- Host
Runtime HostRuntimeowns the lifecycle orchestration forToolKit.- OopGear
Spawn Config - Configuration for a single
OoPgear to be spawned. - OopSpawn
Options - Options for spawning
OoPgears. - RunOptions
- Options for running the
ToolKitrunner. - System
Context - System-level context provided to system gears during the wiring phase.
Enums
- DbOptions
- How the runtime should provide DBs to gears.
- Instance
State - Shutdown
Options - How the runtime should decide when to stop.
Constants
- DEFAULT_
SHUTDOWN_ DEADLINE - Default shutdown deadline for graceful gear stop (35 seconds).
- TOOLKIT_
DIRECTORY_ ENDPOINT_ ENV - Environment variable name for passing directory endpoint to
OoPgears. - TOOLKIT_
MODULE_ CONFIG_ ENV - Environment variable name for passing rendered gear config to
OoPgears.
Functions
- run
- Full cycle is orchestrated by
HostRuntime(seeruntime/host_runtime.rsdocs).