#[gear]Expand description
Main #[gear] attribute macro
ctor must be a Rust expression that evaluates to the gear instance,
e.g. ctor = MyGear::new() or ctor = Default::default().
#[gear]Main #[gear] attribute macro
ctor must be a Rust expression that evaluates to the gear instance,
e.g. ctor = MyGear::new() or ctor = Default::default().