Module runtime

Module runtime 

Modules

shutdown
Shutdown signal handling utilities

Structs

ClientRegistration
A type-erased client registration for injecting clients into the ClientHub.
Endpoint
Represents an endpoint where a gear instance can be reached
GearInstallers
Installers for a specific gear (gear name + service installers).
GearInstance
Represents a single instance of a gear
GearManager
Central registry that tracks all running gear instances in the system. Provides discovery, health tracking, and round-robin load balancing.
GrpcInstallerData
Grouped installers for all gears in the process.
GrpcInstallerStore
Runtime-owned store for gRPC service installers.
HostRuntime
HostRuntime owns the lifecycle orchestration for ToolKit.
OopGearSpawnConfig
Configuration for a single OoP gear to be spawned.
OopSpawnOptions
Options for spawning OoP gears.
RunOptions
Options for running the ToolKit runner.
SystemContext
System-level context provided to system gears during the wiring phase.

Enums

DbOptions
How the runtime should provide DBs to gears.
InstanceState
ShutdownOptions
How the runtime should decide when to stop.

Constants

DEFAULT_SHUTDOWN_DEADLINE
Default shutdown deadline for graceful gear stop (35 seconds).
TOOLKIT_DIRECTORY_ENDPOINT_ENV
Environment variable name for passing directory endpoint to OoP gears.
TOOLKIT_MODULE_CONFIG_ENV
Environment variable name for passing rendered gear config to OoP gears.

Functions

run
Full cycle is orchestrated by HostRuntime (see runtime/host_runtime.rs docs).